From 297c886b72f4e9093973aaa14b66d392f6196634 Mon Sep 17 00:00:00 2001
From: Mark Edgar <medgar123@gmail.com>
Date: Sun, 22 Sep 2013 00:07:49 +0200
Subject: [PATCH] Ignore numlock (Mod2Mask) for button events too.

Conflicts:
	config.def.h
	st.c
---
 config.def.h | 6 +++---
 st.c         | 1 -
 2 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/st.c b/st.c
index 50b58a7..12e1e1f 100644
--- a/st.c
+++ b/st.c
@@ -3579,7 +3579,6 @@ kpress(XEvent *ev) {
 		return;
 
 	len = XmbLookupString(xw.xic, e, buf, sizeof buf, &ksym, &status);
-	e->state &= ~Mod2Mask;
 	/* 1. shortcuts */
 	for(bp = shortcuts; bp < shortcuts + LEN(shortcuts); bp++) {
 		if(ksym == bp->keysym && match(bp->mod, e->state)) {
diff --git a/config.def.h b/config.def.h
index def6c9e..2a7e098 100644
--- a/config.def.h
+++ b/config.def.h
@@ -146,10 +146,10 @@ static Shortcut shortcuts[] = {
 static KeySym mappedkeys[] = { -1 };
 
 /*
  * Which bits of the state should be ignored. By default the state bit for the
  * keyboard layout (XK_SWITCH_MOD) is ignored.
  */
-uint ignoremod = XK_SWITCH_MOD;
+static uint ignoremod = Mod2Mask|XK_SWITCH_MOD;
 
 /* key, mask, output, keypad, cursor, crlf */
 static Key key[] = {
@@ -146,10 +146,10 @@ static Shortcut shortcuts[] = {
 
 /*
- * Which bits of the state should be ignored. By default the state bit for the
- * keyboard layout (XK_SWITCH_MOD) is ignored.
+ * State bits to ignore when matching key or button events.  By default,
+ * numlock (Mod2Mask) and keyboard layout (XK_SWITCH_MOD) are ignored.
  */
-- 
2.20.1